Struct rafx_shader_processor::ShaderProcessorArgs [−][src]
pub struct ShaderProcessorArgs {Show fields
pub glsl_file: Option<PathBuf>,
pub spv_file: Option<PathBuf>,
pub rs_file: Option<PathBuf>,
pub metal_generated_src_file: Option<PathBuf>,
pub gles2_generated_src_file: Option<PathBuf>,
pub gles3_generated_src_file: Option<PathBuf>,
pub cooked_shader_file: Option<PathBuf>,
pub glsl_files: Option<Vec<PathBuf>>,
pub spv_path: Option<PathBuf>,
pub rs_path: Option<PathBuf>,
pub metal_generated_src_path: Option<PathBuf>,
pub gles2_generated_src_path: Option<PathBuf>,
pub gles3_generated_src_path: Option<PathBuf>,
pub cooked_shaders_path: Option<PathBuf>,
pub shader_kind: Option<String>,
pub trace: bool,
pub optimize_shaders: bool,
pub package_vk: bool,
pub package_metal: bool,
pub package_gles2: bool,
pub package_gles3: bool,
pub package_all: bool,
}Fields
glsl_file: Option<PathBuf>spv_file: Option<PathBuf>rs_file: Option<PathBuf>metal_generated_src_file: Option<PathBuf>gles2_generated_src_file: Option<PathBuf>gles3_generated_src_file: Option<PathBuf>cooked_shader_file: Option<PathBuf>glsl_files: Option<Vec<PathBuf>>spv_path: Option<PathBuf>rs_path: Option<PathBuf>metal_generated_src_path: Option<PathBuf>gles2_generated_src_path: Option<PathBuf>gles3_generated_src_path: Option<PathBuf>cooked_shaders_path: Option<PathBuf>shader_kind: Option<String>trace: booloptimize_shaders: boolpackage_vk: boolpackage_metal: boolpackage_gles2: boolpackage_gles3: boolpackage_all: boolTrait Implementations
impl Debug for ShaderProcessorArgs[src]
impl Debug for ShaderProcessorArgs[src]impl StructOpt for ShaderProcessorArgs[src]
impl StructOpt for ShaderProcessorArgs[src]fn from_clap(matches: &ArgMatches<'_>) -> Self[src]
fn from_clap(matches: &ArgMatches<'_>) -> Self[src]Builds the struct from clap::ArgMatches. It’s guaranteed to succeed
if matches originates from an App generated by StructOpt::clap called on
the same type, otherwise it must panic. Read more
fn from_args() -> Self[src]
fn from_args() -> Self[src]Builds the struct from the command line arguments (std::env::args_os).
Calls clap::Error::exit on failure, printing the error message and aborting the program. Read more
fn from_args_safe() -> Result<Self, Error>[src]
fn from_args_safe() -> Result<Self, Error>[src]Builds the struct from the command line arguments (std::env::args_os).
Unlike StructOpt::from_args, returns clap::Error on failure instead of aborting the program,
so calling .exit is up to you. Read more
fn from_iter<I>(iter: I) -> Self where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone, [src]
fn from_iter<I>(iter: I) -> Self where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone, [src]Gets the struct from any iterator such as a Vec of your making.
Print the error message and quit the program in case of failure. Read more
fn from_iter_safe<I>(iter: I) -> Result<Self, Error> where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone, [src]
fn from_iter_safe<I>(iter: I) -> Result<Self, Error> where
I: IntoIterator,
<I as IntoIterator>::Item: Into<OsString>,
<I as IntoIterator>::Item: Clone, [src]Gets the struct from any iterator such as a Vec of your making. Read more
impl StructOptInternal for ShaderProcessorArgs[src]
impl StructOptInternal for ShaderProcessorArgs[src]fn augment_clap<'a, 'b>(app: App<'a, 'b>) -> App<'a, 'b>[src]
fn is_subcommand() -> bool[src]
fn from_subcommand(_sub: (&'b str, Option<&'b ArgMatches<'a>>)) -> Option<Self>[src]